@@ -121,7 +121,15 @@ sub init
   $global->{InFiles}   = [];
   $Formats{$global->{NAME}} = $global;	# All formats we know.
   $FmtList{$global->{NAME}} = $global;  # List of formats for help msgs.
-
+  
+  if ( -e "/etc/papersize" ){
+      open (PAPERSIZE,"</etc/papersize") ||
+	  die "Count not open \"/etc/papersize\" for reading\n";
+      chomp (my $paper = <PAPERSIZE>);
+      $global->{papersize} = "letter" if ( $paper eq "letter");
+      close PAPERSIZE;
+  }
+  
   # automatic language detection: disabled by default
   # {
   #    my $lang;
